<?php

/**
 * Class ShippingServiceTest
 *
 * Lancer tous les tests
 * vendor/bin/phpunit --bootstrap vendor/autoload.php tests/ShippingServiceTest
 *
 * Lancer un test
 * vendor/bin/phpunit --bootstrap vendor/autoload.php tests/ShippingServiceTest --filter testGenerateStickerMultiParcel
 *
 */
class ShippingServiceTest extends \PHPUnit\Framework\TestCase
{
    protected $config;

    protected function setUp()
    {
        $this->config = [
            'login' => '19869502',
            'pass' => '255562',
            'ws_pass' => '255562',
            'format' => 'THE',
            'dir' => __DIR__ . '/../data/',
            'shipper' => [
                'societe' => 'Dedi Agency',
                'civilite' => 'M',
                'nom' => 'Dedi Agency',
                'email' => 'contact@dedi-agency.com',
                'telephone' => '0472870754',
                'adresse_rue' => '37 rue saint Simon',
                'adresse_rue2' => '',
                'adresse_ville' => 'Lyon',
                'adresse_cp' => '69009',
                'pays_code' => 'FR',
                'pays_nom' => 'France',
            ],
        ];
    }

    /**
     * @dataProvider orderProvider
     */
    public function testGenerateSticker($order)
    {

        $shippingService = new \Bydedi\Shipping\Chronopost\ShippingService($this->config);

        $sticker = \Bydedi\Shipping\Chronopost\Sticker::createFromOrder($order);

        try {
            $sticker = $shippingService->generate($sticker);
        } catch (\Bydedi\Shipping\Chronopost\Exception\ChronopostException $e) {
            // print_r($e->getMessage());
            // print_r($e->getChronopostServiceShipping()->getLastRequestHeaders());
            // print_r($e->getChronopostServiceShipping()->getLastRequest());
            // print_r($e->getChronopostServiceShipping()->getLastResponseHeaders());
            // print_r($e->getChronopostServiceShipping()->getLastResponse());
            exit;
        }

        var_dump($sticker->getUrlPdf());
        var_dump($sticker->getTracking());

        // $this->assertFileExists($sticker->getUrlPdf());
    }

    /**
     * @dataProvider orderProvider
     */
    public function testGenerateStickerMultiParcel($order)
    {
        $shippingService = new \Bydedi\Shipping\Chronopost\ShippingService($this->config);

        $sticker = \Bydedi\Shipping\Chronopost\Sticker::createFromOrder($order);
        $sticker->setNumberOfParcel(3);

        try {
            $sticker = $shippingService->generate($sticker);
        } catch (\Bydedi\Shipping\Chronopost\Exception\ChronopostException $e) {
            print_r("error");
            // print_r($e->getMessage());
            // print_r($e->getChronopostServiceShipping()->getLastRequestHeaders());
            print_r($e->getChronopostServiceShipping()->getLastRequest());
            print_r($e->getChronopostServiceShipping()->getLastResponseHeaders());
            print_r($e->getChronopostServiceShipping()->getLastResponse());
            exit;
        }

        // print_r($shippingService->getChronopostServiceShipping()->getLastRequest());
        // print_r($shippingService->getChronopostServiceShipping()->getLastResponse());

        var_dump($sticker->getUrlPdf());
        var_dump($sticker->getTracking());
    }

    public function orderProvider()
    {
        return [
            'order domicile' => [
                [
                    'livraison_societe' => '',
                    'livraison_prenom' => 'Dedi',
                    'livraison_nom' => 'Agency',
                    'livraison_rue' => '1 rue de la paix',
                    'livraison_rue2' => '',
                    'livraison_ville' => 'Paris',
                    'livraison_cp' => '75001',
                    'livraison_telephone' => '0602023568',
                    'client_prenom' => 'Dedi',
                    'client_nom' => 'Agency',
                    'client_email' => 'contact@dedi-agency.com',
                    'client_telephone' => '',
                    'commande_livraison_code' => 'CHRONO',
                    'livraison_pays_code' => 'FR',
                    'livraison_pays' => 'FR',
                    'commande_port_ht' => 5.90,
                    'commande_poids' => 1500,
                    'relais_id' => NULL,
                ]
            ],
            // 'order relais' => [],
        ];
    }
}
